Index: branches/stable/mondo/src/common/libmondo-fifo-EXT.h
===================================================================
--- branches/2.05/mondo/mondo/common/libmondo-fifo-EXT.h (revision 128)
+++ branches/stable/mondo/src/common/libmondo-fifo-EXT.h (revision 1103)
@@ -4,3 +4,3 @@
 									long internal_block_size);
 extern void sigpipe_occurred(int);
-extern void kill_buffer();
+extern void kill_buffer(void);
Index: branches/stable/mondo/src/common/libmondo-filelist.c
===================================================================
--- branches/stable/mondo/src/common/libmondo-filelist.c (revision 1082)
+++ branches/stable/mondo/src/common/libmondo-filelist.c (revision 1103)
@@ -420,5 +420,5 @@
 	}
 	filelist->ch = '\0';
-	mr_free(filelist);
+	mr_free((void*) filelist);
 	depth--;
 	if (depth == 0) {
@@ -429,15 +429,15 @@
 
 
-int call_exe_and_pipe_output_to_fd(char *syscall, FILE * pout)
+int call_exe_and_pipe_output_to_fd(char *sys_call, FILE * pout)
 {
 	FILE *pattr;
 	char *tmp;
-	pattr = popen(syscall, "r");
+	pattr = popen(sys_call, "r");
 	if (!pattr) {
-		log_msg(1, "Failed to open fattr() %s", syscall);
+		log_msg(1, "Failed to open fattr() %s", sys_call);
 		return (1);
 	}
 	if (feof(pattr)) {
-		log_msg(1, "Failed to call fattr() %s", syscall);
+		log_msg(1, "Failed to call fattr() %s", sys_call);
 		paranoid_pclose(pattr);
 		return (2);
@@ -461,5 +461,5 @@
 	FILE *pout;
 	char *pout_command;
-	char *syscall;
+	char *sys_call;
 	char *file_to_analyze;
 	char *strtmp = NULL;
@@ -487,8 +487,8 @@
 		log_msg(8, "Analyzing %s", file_to_analyze);
 		asprintf(&strtmp, syscall_sprintf, mr_stresc(file_to_analyze, "`$\\\"", '\\'));
-		asprintf(&syscall, "%s 2>> /dev/null", strtmp);	// " MONDO_LOGFILE);
+		asprintf(&sys_call, "%s 2>> /dev/null", strtmp);	// " MONDO_LOGFILE);
 		mr_free(strtmp);
-		call_exe_and_pipe_output_to_fd(syscall, pout);
-		mr_free(syscall);
+		call_exe_and_pipe_output_to_fd(sys_call, pout);
+		mr_free(sys_call);
 	}
 	paranoid_fclose(fin);
Index: branches/stable/mondo/src/common/libmondo-raid.c
===================================================================
--- branches/stable/mondo/src/common/libmondo-raid.c (revision 1080)
+++ branches/stable/mondo/src/common/libmondo-raid.c (revision 1103)
@@ -232,5 +232,5 @@
  */
 void add_disk_to_raid_device(struct list_of_disks *disklist,
-							 char *device_to_add, int index)
+							 char *device_to_add, int idx)
 {
 	int items;
@@ -240,5 +240,5 @@
 	items = disklist->entries;
 	strcpy(disklist->el[items].device, device_to_add);
-	disklist->el[items].index = index;
+	disklist->el[items].index = idx;
 	items++;
 	disklist->entries = items;
@@ -696,5 +696,4 @@
 
 	struct list_of_disks *disklist;
-	int index;
 	int v;
 
@@ -754,6 +753,5 @@
 			log_it(tmp);
 		} else {
-			index = atoi(valueB);
-			add_disk_to_raid_device(disklist, value, index);
+			add_disk_to_raid_device(disklist, value, atoi(valueB));
 		}
 	} else {
Index: branches/stable/mondo/src/common/libmondo-tools.h
===================================================================
--- branches/2.05/mondo/mondo/common/libmondo-tools.h (revision 128)
+++ branches/stable/mondo/src/common/libmondo-tools.h (revision 1103)
@@ -3,7 +3,10 @@
 	 */
 
+#ifndef LIBMONDO_TOOLS_H
+# define LIBMONDO_TOOLS_H
+
 void clean_up_KDE_desktop_if_necessary(void);
 
-long get_time();
+long get_time(void);
 extern void (*log_debug_msg) (int debug_level, const char *szFile,
 							  const char *szFunction, int nLine,
@@ -21,5 +24,5 @@
 #endif
 void log_trace(char *o);
-int some_basic_system_sanity_checks();
+int some_basic_system_sanity_checks(void);
 
 
@@ -47,6 +50,6 @@
 void free_libmondo_global_strings(void);
 
-double get_kernel_version();
-char *get_architecture();
+double get_kernel_version(void);
+char *get_architecture(void);
 bool does_nonMS_partition_exist(void);
 void stop_magicdev_if_necessary(void);
@@ -54,2 +57,5 @@
 void stop_autofs_if_necessary(void);
 void restart_autofs_if_necessary(void);
+
+#endif /* LIBMONDO_TOOLS_H */
+
Index: branches/stable/mondo/src/common/newt-specific.c
===================================================================
--- branches/stable/mondo/src/common/newt-specific.c (revision 1080)
+++ branches/stable/mondo/src/common/newt-specific.c (revision 1103)
@@ -96,6 +96,6 @@
 	 g_xmondo_stdout[MAX_NEWT_COMMENT_LEN];	///< .... @bug Unneeded w/current XMondo.
 	bool g_called_by_xmondo = FALSE;	///< @bug Unneeded w/current XMondo.
-	char *g_erase_tmpdir_and_scratchdir;	///< The command to run to erase the tmpdir and scratchdir at the end of Mondo.
-	char *g_selfmounted_isodir;	///< Holds the NFS mountpoint if mounted via mondoarchive.
+	char *g_erase_tmpdir_and_scratchdir = NULL;	///< The command to run to erase the tmpdir and scratchdir at the end of Mondo.
+	char *g_selfmounted_isodir = NULL;	///< Holds the NFS mountpoint if mounted via mondoarchive.
 
 /* @} - end of globalGroup */
@@ -375,9 +375,9 @@
  */
 	void
-	 finish(int signal) {
+	 finish(int signal_code) {
 		char *command;
 		malloc_string(command);
 
-		/*  if (signal==0) { popup_and_OK("Please press <enter> to quit."); } */
+		/*  if (signal_code==0) { popup_and_OK("Please press <enter> to quit."); } */
 
 		/* newtPopHelpLine(); */
@@ -411,8 +411,8 @@
 //  system("clear");
 //  iamhere("Finished calling newtFinished");
-		printf("Execution run ended; result=%d\n", signal);
+		printf("Execution run ended; result=%d\n", signal_code);
 		printf("Type 'less %s' to see the output log\n", MONDO_LOGFILE);
 		free_libmondo_global_strings();
-		exit(signal);
+		exit(signal_code);
 	}
 
@@ -693,5 +693,5 @@
 	void
 	 popup_and_OK(char *prompt) {
-		char ch;
+		int ch;
 
 		assert_string_is_neither_NULL_nor_zerolength(prompt);
Index: branches/stable/mondo/src/common/newt-specific.h
===================================================================
--- branches/2.05/mondo/mondo/common/newt-specific.h (revision 128)
+++ branches/stable/mondo/src/common/newt-specific.h (revision 1103)
@@ -3,5 +3,6 @@
  */
 
-
+#ifndef NEWT_SPECIFIC_H
+# define NEWT_SPECIFIC_H
 #ifndef H_NEWT
 #include <newt.h>
@@ -11,5 +12,5 @@
 bool ask_me_OK_or_cancel(char *prompt);
 void close_evalcall_form(void);
-void close_progress_form();
+void close_progress_form(void);
 void fatal_error(char *error_string);
 void finish(int signal);
@@ -23,6 +24,6 @@
 bool popup_and_get_string(char *title, char *b, char *output, int maxsize);
 bool popup_with_buttons(char *p, char *button1, char *button2);
-void refresh_log_screen();
-void setup_newt_stuff();
+void refresh_log_screen(void);
+void setup_newt_stuff(void);
 void update_evalcall_form_ratio(int num, int denom);
 void update_evalcall_form(int curr);
@@ -36,6 +37,9 @@
 
 t_bkptype which_backup_media_type(bool);
-int which_compression_level();
+int which_compression_level(void);
 
 
 void popup_changelist_from_file(char *source_file);
+
+#endif /* NEWT_SPECIFIC_H */
+
Index: branches/stable/mondo/src/include/my-stuff.h
===================================================================
--- branches/stable/mondo/src/include/my-stuff.h (revision 1087)
+++ branches/stable/mondo/src/include/my-stuff.h (revision 1103)
@@ -275,5 +275,5 @@
  * Free variables and call finish(@p x).
  */
-#define paranoid_MR_finish(x) {free_MR_global_filenames (); if (g_bkpinfo_DONTUSETHIS) mr_free ( g_bkpinfo_DONTUSETHIS ); finish(x); }
+#define paranoid_MR_finish(x) {free_MR_global_filenames (); if (g_bkpinfo_DONTUSETHIS) mr_free ( (void*) g_bkpinfo_DONTUSETHIS ); finish(x); }
 
 /**
Index: branches/stable/mondo/src/mondorestore/mondo-prep.c
===================================================================
--- branches/stable/mondo/src/mondorestore/mondo-prep.c (revision 1080)
+++ branches/stable/mondo/src/mondorestore/mondo-prep.c (revision 1103)
@@ -2002,5 +2002,5 @@
 	system("clear");
 	newtResume();
-	mr_free(drivelist);
+	mr_free((void*) drivelist);
 	return (retval);
 }
@@ -2605,5 +2605,5 @@
 	}
 	log_to_screen("Mountlist adjusted to suit current hard drive(s)");
-	mr_free(drivelist);
+	mr_free((void*) drivelist);
 }
 
Index: branches/stable/mondo/src/mondorestore/mondo-rstr-newt.c
===================================================================
--- branches/stable/mondo/src/mondorestore/mondo-rstr-newt.c (revision 1087)
+++ branches/stable/mondo/src/mondorestore/mondo-rstr-newt.c (revision 1103)
@@ -76,5 +76,5 @@
 	/** int ****************************************************************/
 	int i = 0;
-	int index = 0;
+	int idx = 0;
 	int currline = 0;
 	int items = 0;
@@ -109,10 +109,10 @@
 			log_it("I don't know what this button does");
 		} else {
-			index = find_next_free_index_in_disklist(disklist);
+			idx = find_next_free_index_in_disklist(disklist);
 
 			items = disklist->entries;
 			strcpy(disklist->el[items].device,
 				   unallocated_raid_partitions->el[currline].device);
-			disklist->el[items].index = index;
+			disklist->el[items].index = idx;
 			disklist->entries = ++items;
 
@@ -1660,5 +1660,5 @@
 	mr_free(sz_parity_disks);
 	mr_free(sz_failed_disks);
-	mr_free(bkp_raidrec);
+	mr_free((void*) bkp_raidrec);
 #endif
 }
@@ -2188,5 +2188,5 @@
 
 	/** int ***************************************************************/
-	int index = -1;
+	int idx = -1;
 	int pos = 0;
 
@@ -2198,13 +2198,13 @@
 	for (done = FALSE; !done;) {
 		for (pos = 0;
-			 pos < disklist->entries && disklist->el[pos].index <= index;
+			 pos < disklist->entries && disklist->el[pos].index <= idx;
 			 pos++);
 		if (pos >= disklist->entries) {
 			done = TRUE;
 		} else {
-			index = disklist->el[pos].index;
-		}
-	}
-	return (index + 1);
+			idx = disklist->el[pos].index;
+		}
+	}
+	return (idx + 1);
 }
 
@@ -2389,5 +2389,5 @@
  * Dummy function that proves that we can get to the point where Mondo is run.
  */
-void nuke_mode_dummy()
+void nuke_mode_dummy(void)
 {
 
@@ -2846,8 +2846,8 @@
 	mr_free(sz_res);
 	mr_free(header_text);
-	mr_free(bkp_raidrec);
-	mr_free(bkp_disklist);
-	mr_free(bkp_raidlist);
-	mr_free(unallocated_raid_partitions);
+	mr_free((void*) bkp_raidrec);
+	mr_free((void*) bkp_disklist);
+	mr_free((void*) bkp_raidlist);
+	mr_free((void*) unallocated_raid_partitions);
 }
 #endif
Index: branches/stable/mondo/src/mondorestore/mondo-rstr-newt.h
===================================================================
--- branches/stable/mondo/src/mondorestore/mondo-rstr-newt.h (revision 1067)
+++ branches/stable/mondo/src/mondorestore/mondo-rstr-newt.h (revision 1103)
@@ -157,5 +157,5 @@
 char *mountlist_entry_to_string(struct mountlist_itself *, int);
 void mvaddstr_and_log_it(int, int, char *);
-void nuke_mode_dummy();
+void nuke_mode_dummy(void);
 char *number_of_disks_as_string(int, char *);
 void open_evalcall_form(char *);
Index: branches/stable/mondo/src/mondorestore/mondo-rstr-tools-EXT.h
===================================================================
--- branches/stable/mondo/src/mondorestore/mondo-rstr-tools-EXT.h (revision 912)
+++ branches/stable/mondo/src/mondorestore/mondo-rstr-tools-EXT.h (revision 1103)
@@ -3,5 +3,5 @@
  */
 
-extern void free_MR_global_filenames();
+extern void free_MR_global_filenames(void);
 extern void get_cfg_file_from_archive_or_bust(struct s_bkpinfo *);
 extern bool is_file_in_list(char *, char *, char *);	/* needle, haystack, preamble */
Index: branches/stable/mondo/src/mondorestore/mondo-rstr-tools.c
===================================================================
--- branches/stable/mondo/src/mondorestore/mondo-rstr-tools.c (revision 1102)
+++ branches/stable/mondo/src/mondorestore/mondo-rstr-tools.c (revision 1103)
@@ -53,5 +53,5 @@
  * Free the malloc()s for the filename variables.
  */
-void free_MR_global_filenames()
+void free_MR_global_filenames(void)
 {
 	mr_free(g_biggielist_txt);
@@ -556,5 +556,5 @@
 	}
 	run_program_and_log_output("df -m", 3);
-	mr_free(mountlist);
+	mr_free((void*) mountlist);
 	mr_free(tmp);
 	mr_free(format);
@@ -2178,5 +2178,5 @@
 		log_to_screen("All partitions were unmounted OK.");
 	}
-	mr_free(mountlist);
+	mr_free((void*) mountlist);
 	mr_free(command);
 	mr_free(tmp);
@@ -2557,4 +2557,4 @@
 	}
 	mr_free(screen_message);
-	mr_free(raidlist);
-}
+	mr_free((void*) raidlist);
+}
Index: branches/stable/mondo/src/mondorestore/mondo-rstr-tools.h
===================================================================
--- branches/stable/mondo/src/mondorestore/mondo-rstr-tools.h (revision 1052)
+++ branches/stable/mondo/src/mondorestore/mondo-rstr-tools.h (revision 1103)
@@ -3,5 +3,5 @@
  */
 
-void free_global_filenames();
+void free_global_filenames(void);
 void get_cfg_file_from_archive_or_bust(struct s_bkpinfo *);
 bool is_file_in_list(char *, char *, char *);	/* needle, haystack, preamble */
